==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/HVCore/src/AbstractResults.cpp <==
/***************************************************************************
**
**  This file is part of HVCore.
**
**  HVCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  HVCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-05-25
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "AbstractResults.h"
#include "AbstractStation.h"
#include "HVParameters.h"

namespace HVCore {

  /*!
    \class AbstractResults AbstractResults.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  /*!
    Description of constructor still missing
  */
  AbstractResults::AbstractResults(AbstractStation * parent)
    : QObject(parent)
  {
    TRACE;
    _category=tr("Default");
  }

  /*!
    Description of destructor still missing
  */
  AbstractResults::~AbstractResults()
  {
  }

  AbstractStation * AbstractResults::parent() const
  {
    return static_cast<AbstractStation *>(QObject::parent());
  }

  void AbstractResults::setWindowColor(int winIndex, const Color& col)
  {
    Q_UNUSED(winIndex);
    Q_UNUSED(col);
  }

  void AbstractResults::setWindowColor(const QVector<int>* selCurves, const Color& col)
  {
    Q_UNUSED(selCurves);
    Q_UNUSED(col);
  }

  void AbstractResults::setStatistics()
  {

  }

  void AbstractResults::setPeaks()
  {

  }

  QString AbstractResults::unit() const
  {
    TRACE;
    return parent()->originalSignals()->unit();
  }


} // namespace HVCore

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/HVCore/src/AbstractResults.cpp <==
/***************************************************************************
**
**  This file is part of HVCore.
**
**  HVCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  HVCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-05-25
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "AbstractResults.h"
#include "AbstractStation.h"
#include "HVParameters.h"

namespace HVCore {

  /*!
    \class AbstractResults AbstractResults.h
    \brief Brief description of class still missing

    Full description of class still missing
  */

  /*!
    Description of constructor still missing
  */
  AbstractResults::AbstractResults(AbstractStation * parent)
    : QObject(parent)
  {
    TRACE;
    _category=tr("Default");
  }

  /*!
    Description of destructor still missing
  */
  AbstractResults::~AbstractResults()
  {
  }

  AbstractStation * AbstractResults::parent() const
  {
    return static_cast<AbstractStation *>(QObject::parent());
  }

  void AbstractResults::setWindowColor(int winIndex, const Color& col)
  {
    Q_UNUSED(winIndex);
    Q_UNUSED(col);
  }

  void AbstractResults::setWindowColor(const QList<int>* selCurves, const Color& col)
  {
    Q_UNUSED(selCurves);
    Q_UNUSED(col);
  }

  void AbstractResults::setStatistics()
  {

  }

  void AbstractResults::setPeaks()
  {

  }

  QString AbstractResults::unit() const
  {
    TRACE;
    return parent()->originalSignals()->unit();
  }


} // namespace HVCore
